pub fn format_datetime(dt: OrbitalDateTime, format: DatetimeFormat) -> StringExpand description
Display a bound datetime value using its embedded timezone.
pub fn format_datetime(dt: OrbitalDateTime, format: DatetimeFormat) -> StringDisplay a bound datetime value using its embedded timezone.