pub struct UseAnchorPositionOptions {
pub mount_ref: Option<NodeRef<Div>>,
pub dismiss_on_anchor_hidden: bool,
pub on_dismiss: Option<Callback<()>>,
}Expand description
Optional positioning behavior for [use_anchor_position].
Fields
mount_ref: Option<NodeRef<Div>>When set, panel coordinates are relative to this mount element.
Dismiss the overlay when the anchor no longer intersects its scrollport.
on_dismiss: Option<Callback<()>>Called to close the overlay (typically [OverlayDismiss::close]).